mainline
========

Simple yet powerful python dependency injection.

Tested with Python 2.7, 3.4, 3.5.

|Test Status| |Coverage Status| |Documentation Status|

- Docs: http://mainline.readthedocs.org/en/latest
- API Docs: http://mainline.readthedocs.org/en/latest/mainline.html
- PyPi: https://pypi.python.org/pypi/mainline


Installation
------------

.. code:: sh

    pip install mainline



Running tests
-------------

Tox is used to handle testing multiple python versions.

.. code:: sh

    tox


.. |Test Status| image:: https://circleci.com/gh/vertical-knowledge/mainline.svg?style=svg
   :target: https://circleci.com/gh/vertical-knowledge/mainline
.. |Coverage Status| image:: https://coveralls.io/repos/vertical-knowledge/mainline/badge.svg?branch=develop&service=github
   :target: https://coveralls.io/github/vertical-knowledge/mainline?branch=develop
.. |Documentation Status| image:: https://readthedocs.org/projects/mainline/badge/?version=latest
   :target: http://mainline.readthedocs.org/en/latest/?badge=latest

